@@ -1,17 +1,13 @@
-# 
+#
 # This file is part of Config-Model
-# 
-# This software is Copyright (c) 2010 by Dominique Dumont.
-# 
+#
+# This software is Copyright (c) 2011 by Dominique Dumont, Krzysztof Tyszecki.
+#
 # This is free software, licensed under:
-# 
+#
 #   The GNU Lesser General Public License, Version 2.1, February 1999
-# 
-# $Author$
-# $Date$
-# $Revision$
-
-#    Copyright (c) 2005,2006 Dominique Dumont.
+#
+#    Copyright (c) 2005-2011 Dominique Dumont.
 #
 #    This file is part of Config-Model.
 #
@@ -34,7 +30,7 @@ use warnings ;
 
 # this line is necessary to run the example without installing
 # Config::Model
-use lib ('../../blib/lib') ;
+use lib ('../../lib') ;
 
 use Config::Model ;
 use Getopt::Long ;
@@ -44,24 +40,24 @@ use File::Path ;
 use vars qw/$model/ ;
 
 
-my $use_sample = 0;
-GetOptions ("use_sample" => \$use_sample);
+my $use_etc = 0;
+GetOptions ("use_etc" => \$use_etc);
 
-my $fstab_file = $use_sample ? 'fstab.sample' : '/etc/fstab' ;
+my $fstab_file = $use_etc ?  '/etc/fstab' : 'fstab.sample'  ;
 
-$model = Config::Model -> new(model_dir => '.') ;
+$model = Config::Model -> new(model_dir => 'lib/Config/Model/models') ;
 
-my $instance = $model -> instance( root_class_name => 'Fstab',
+my $instance = $model -> instance( root_class_name => 'MyFstab',
 				   instance_name => 'test',
 				 ) ;
 
 my $root= $instance -> config_root ;
 
 print "
-The first part of this example program will read your $fstab_file.
-Bear in mind that the Fstab model provided in this example is far from
-being complete.  If this program fails to read your /etc/fstab, please
-re-run it with '-use_sample' option.
+The first part of this example program will read a sample fstab file. You
+can run this program with -use_etc to load /etc/fstab.
+Just bear in mind that the Fstab model provided in this example is far from
+being complete and may fail to read your file.
 
 ";
 
