@@ -27,7 +27,7 @@
 
 package Config::Model::AnyId ;
 {
-  $Config::Model::AnyId::VERSION = '1.260';
+  $Config::Model::AnyId::VERSION = '1.265';
 }
 use Config::Model::Exception ;
 use Config::Model::Warper ;
@@ -56,7 +56,7 @@ Config::Model::AnyId - Base class for hash or list element
 
 =head1 VERSION
 
-version 1.260
+version 1.265
 
 =head1 SYNOPSIS
 
@@ -255,7 +255,8 @@ Specify the minimum value (optional, only for hash and for integer index)
 
 =item max_index
 
-Specify the maximum value (optional, only for integer index)
+Specify the maximum value (optional, only for list or for hash with 
+integer index)
 
 =item max_nb
 
@@ -340,6 +341,10 @@ Specifies the number of elements to create automatically. E.g.  C<<
 auto_create_ids => 4 >> will initialize the list with 4 undef elements.
 (valid only for list elements)
 
+=item convert => [uc | lc ]
+
+The hash key will be converted to uppercase (uc) or lowercase (lc).
+
 =item warp
 
 See L</"Warp: dynamic value configuration"> below.
@@ -429,7 +434,7 @@ my @common_params =  qw/min_index max_index max_nb default_with_init default_key
                         allow_keys allow_keys_from allow_keys_matching
                         warn_if_key_match warn_unless_key_match/ ;
 
-my @allowed_warp_params = (@common_params,qw/experience level/) ;
+my @allowed_warp_params = (@common_params,qw/experience level convert/) ;
 
 
 # this method can be called by the warp mechanism to alter (warp) the
@@ -449,6 +454,8 @@ sub set_properties {
 
     map { $self->{$_} =  delete $args{$_} if defined $args{$_} }
       @common_params ;
+      
+    $self->set_convert        ( \%args ) if defined $args{convert};
 
     Config::Model::Exception::Model
         ->throw (
@@ -484,7 +491,7 @@ sub set_properties {
             Config::Model::Exception::WrongValue 
                 -> throw (
                           error => "Error while setting id property:".
-                          join("\n\t",@{$self->{error}}),
+                          join("\n\t",@{$self->{error_list}}),
                           object => $self
                          ) ;
         }
@@ -831,6 +838,7 @@ sub check {
     map { warn ("Warning in '".$self->location."': $_\n") } @warn unless $silent;
     
     $self->{warning_list} = \@warn ;
+    $self->{error_list}   = \@error ;
 
     return scalar @error ? 0 : 1 ;
 }
@@ -887,7 +895,7 @@ sub check_idx {
           $self->warp_error  ;
     }
 
-    $self->{error} = \@error ;
+    $self->{error_list} = \@error ;
 
     if (@warn) {
         $self->{warning_hash}{$idx} = \@warn ;
@@ -973,7 +981,7 @@ sub check_duplicates {
     my @to_delete ;
     foreach my $i ( $self->get_all_indexes ) {
         my $v = $self->fetch_with_id(index => $i, check => 'no')->fetch;
-        next unless defined $v ;
+        next unless $v ;
         $h{$v} = 0 unless defined $h{$v} ;
         $h{$v}++;
         if ($h{$v} > 1) {
@@ -1024,6 +1032,10 @@ sub fetch_with_id {
     my $check = $self->_check_check($args{check}) ;    
     my $idx = $args{index} ;
 
+    $idx = $self->{convert_sub}($idx) 
+      if (defined $self->{convert_sub} and defined $idx) ;
+
+
     $self->warp 
       if ($self->{warp} and @{$self->{warp_info}{computed_master}});
 
@@ -1036,7 +1048,7 @@ sub fetch_with_id {
     else {
         Config::Model::Exception::WrongValue 
             -> throw (
-                      error => join("\n\t",@{$self->{error}}),
+                      error => join("\n\t",@{$self->{error_list}}),
                       object => $self
                      ) ;
     }
@@ -1112,7 +1124,7 @@ sub copy {
     else {
         Config::Model::Exception::WrongValue 
             -> throw (
-                      error => join("\n\t",@{$self->{error}}),
+                      error => join("\n\t",@{$self->{error_list}}),
                       object => $self
                      ) ;
     }
@@ -1180,7 +1192,7 @@ sub fetch_all_values {
         }
         else {
             Config::Model::Exception::WrongValue->throw(
-                error  => join( "\n\t", @{ $self->{error} } ),
+                error  => join( "\n\t", @{ $self->{error_list} } ),
                 object => $self
             );
         }
@@ -1435,8 +1447,8 @@ Returns the error messages of this object (if any)
 
 sub error_msg {
     my $self = shift ;
-    return unless $self->{error} ;
-    return wantarray ? @{$self->{error}} : join("\n\t",@{ $self ->{error}}) ;
+    return unless $self->{error_list} ;
+    return wantarray ? @{$self->{error_list}} : join("\n\t",@{ $self ->{error_list}}) ;
 }
 
 1;
