@@ -27,7 +27,7 @@
 
 package Config::Model::CheckList ;
 {
-  $Config::Model::CheckList::VERSION = '1.260';
+  $Config::Model::CheckList::VERSION = '1.265';
 }
 use Config::Model::Exception ;
 use Config::Model::IdElementReference ;
@@ -49,7 +49,7 @@ Config::Model::CheckList - Handle check list element
 
 =head1 VERSION
 
-version 1.260
+version 1.265
 
 =head1 SYNOPSIS
 
@@ -131,7 +131,7 @@ sub new {
     my $type = shift;
     my %args = @_ ;
 
-    my $self = { data => {}, preset => {} , ordered_data => [] } ;
+    my $self = { data => {}, preset => {} , layered => {} , ordered_data => [] } ;
     bless $self,$type;
 
     foreach my $p (qw/element_name instance config_model/) {
@@ -376,7 +376,7 @@ sub setup_choice {
     $self->{choice}  = \@choice ;
 
     # cleanup current preset and data if it does not fit current choices
-    foreach my $field (qw/preset data/) {
+    foreach my $field (qw/preset data layered/) {
 	next unless defined $self->{$field} ; # do not create if not present
 	foreach my $item (keys %{$self->{$field}}) {
 	    delete $self->{$field}{$item} unless defined $self->{choice_hash}{$item} ;
@@ -577,6 +577,9 @@ sub store {
 	if ($inst->preset) {
 	    $self->{preset}{$choice} = $value ;
 	}
+	elsif ($inst->layered) {
+	    $self->{layered}{$choice} = $value ;
+	}
 	else {
 	    $self->{data}{$choice} = $value ;
 	}
@@ -627,12 +630,12 @@ Return 1 if the given C<choice> was set. Returns 0 otherwise.
 C<check> parameter decide on behavior in case of invalid
 choice value: either die (if yes) or discard bad value (if skip)
 
-C<mode> is either: custom standard preset default upstream_default
+C<mode> is either: custom standard preset default layered upstream_default
 
 =cut
 
 my %accept_mode = map { ( $_ => 1) } 
-                      qw/custom standard preset default upstream_default/;
+                      qw/custom standard preset default layered upstream_default/;
 
 
 sub is_checked {
@@ -660,6 +663,7 @@ sub is_checked {
 	my $result 
 	  = $type eq 'custom'           ? ( $dat->{$choice} && ! $std_v ? 1 : 0 )
           : $type eq 'preset'           ? $pre->{$choice}
+          : $type eq 'layered'          ? $self->{layered}{$choice}
           : $type eq 'upstream_default' ? $ud ->{$choice}
           : $type eq 'default'          ? $def->{$choice}
           : $type eq 'standard'         ? $std_v
@@ -790,6 +794,10 @@ The list set in preset mode or checked by default.
 
 The default list (defined by the configuration model)
 
+=item layered
+
+The list specified in layered mode. 
+
 =item upstream_default
 
 The list implemented by upstream project (defined in the configuration
@@ -826,22 +834,26 @@ sub get_checked_list_as_hash {
     my $dat = $self->{data} ;
     my $pre = $self->{preset} ;
     my $def = $self->{default_data} ;
+    my $lay = $self->{layered} ;
     my $ud  = $self->{upstream_default_data} ;
 
     # copy hash and return it
-    my %std = (%h, %$def, %$pre ) ;
+    my %std = (%h, %$ud, %$lay, %$def, %$pre ) ;
+
+    # custom test must compare the whole list at once, not just one item at a time.
     my %result 
-      = $mode eq 'custom'   ? (%h, map { $dat->{$_} && ! $std{$_} ? ($_,1) : ()} keys %$dat )
+      = $mode eq 'custom'   ? ( ( grep { $dat->{$_} xor $std{$_} } keys %h ) ? (%h, %$pre ,%$dat) : %h )
       : $mode eq 'preset'   ? (%h, %$pre )
-      : $mode eq 'upstream_default' ? %$ud
-      : $mode eq 'default'          ? %$def
+      : $mode eq 'layered'  ? (%h, %$lay )
+      : $mode eq 'upstream_default' ? (%h, %$ud) 
+      : $mode eq 'default'          ? (%h, %$def )
       : $mode eq 'standard' ? %std
-      :                       (%std, %$dat );
+      :                       (%h, %$def, %$pre, %$dat );
 
     return wantarray ? %result : \%result;
 }
 
-=head2 get_checked_list ( [ custom | preset | standard | default ] )
+=head2 get_checked_list ( < mode >  )
 
 Returns a list (or a list ref) of all checked items (i.e. all items
 set to 1). 
@@ -857,7 +869,7 @@ sub get_checked_list {
     return wantarray ? @res : \@res ;
 }
 
-=head2 fetch ( [ custom | preset | standard | default ] )
+=head2 fetch ( < mode > )
 
 Returns a string listing the checked items (i.e. "A,B,C")
 
@@ -878,7 +890,11 @@ sub fetch_preset {
     return join (',', $self->get_checked_list('preset'));
 }
 
-=head2 get( path  [, custom | preset | standard | default ])
+sub fetch_layered {
+    my $self = shift ;
+    return join (',', $self->get_checked_list('layered'));
+}
+=head2 get( path  [, < mode> ] )
 
 Get a value from a directory like path.
 
@@ -945,6 +961,7 @@ sub store_set { goto &set_checked_list }
 
 sub set_checked_list {
     my $self = shift ;
+    $logger->debug("called with @_");
     $self->clear ;
     $self->{ordered_data} = [ @_ ] ; # copy list
     $self->check (@_) ;
