@@ -27,7 +27,7 @@
 
 package Config::Model::ListId ;
 {
-  $Config::Model::ListId::VERSION = '1.260';
+  $Config::Model::ListId::VERSION = '1.265';
 }
 use Config::Model::Exception ;
 use Scalar::Util qw(weaken) ;
@@ -46,7 +46,7 @@ Config::Model::ListId - Handle list element for configuration model
 
 =head1 VERSION
 
-version 1.260
+version 1.265
 
 =head1 SYNOPSIS
 
@@ -223,10 +223,14 @@ sub store_set {
         %args = @_; # note that $r was shifted out of @_
     }
 
+    my @comments = @{ $args{comment} || [] } ;
+
     my $idx = 0 ;
     foreach (@v) { 
         if (defined $_) {
-            $self->fetch_with_id( $idx++ )->store(%args, value => $_);
+            my $v_obj = $self->fetch_with_id( $idx++ ) ;
+            $v_obj -> store(%args, value => $_);
+            $v_obj->annotation(shift @comments) if @comments ;
         }
         else {
             $self->{data}[$idx] = undef ; # detruit l'objet pas bon!
@@ -339,17 +343,20 @@ Example:
 sub push_x {
     my $self = shift ;
     my %args = @_ ;
-    my $check = $args{check} || 'yes'; 
+    my $check = delete $args{check} || 'yes'; 
     my $idx   = scalar @{$self->{data}};
-    my @v = @{$args{values}}  ;
-    my @a = @{$args{annotation} || [] } ;
+    my $v_arg = delete $args{values} ;
+    my @v = ref ($v_arg) ? @$v_arg : ($v_arg)  ;
+    my $anno = delete $args{annotation} ;
+    my @a = ref ($anno) ? @$anno : $anno ? ($anno) : () ;
+    
+    croak("push_x: unexpected parameter ",join(' ',keys %args)) if %args ;
     
     while (@v) {
         my $val = shift @v ;
-        my $a   = shift @a ;
         my $obj = $self->fetch_with_id( $idx++ );
         $obj->store( $val ) ;
-        $obj->annotation($a) if $a ;
+        $obj->annotation(shift @a) if @a ;
     }
 }
 
